@@ -1,4 +1,6 @@
-/* GDM - The GNOME Display Manager
+/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*-
+ *
+ * GDM - The GNOME Display Manager
  * Copyright (C) 1999, 2000 Martin K. Petersen <mkp@mkp.net>
  *
  * This file Copyright (c) 2003 George Lebl
@@ -20,12 +22,15 @@
  */
 
 #include "config.h"
+
+#include <unistd.h>
 #include <locale.h>
-#include <libgnome/libgnome.h>
-#include <libgnomeui/libgnomeui.h>
 #include <string.h>
 #include <syslog.h>
 
+#include <glib/gi18n.h>
+#include <gtk/gtk.h>
+
 #include <vicious.h>
 #include "viciousui.h"
 
@@ -33,143 +38,7 @@
 
 #include "gdmwm.h"
 #include "gdmcommon.h"
-
-extern gchar *GdmInfoMsgFile;
-extern gchar *GdmInfoMsgFont;
-extern gchar *GdmSoundProgram;
-extern gboolean GdmSoundOnLoginReady;
-extern gchar *GdmSoundOnLoginReadyFile;
-
-void
-gdm_common_show_info_msg (void)
-{
-	GtkWidget *dialog, *label;
-	gchar *InfoMsg;
-	gsize InfoMsgLength;
-
-	if (ve_string_empty (GdmInfoMsgFile) ||
-	    ! g_file_test (GdmInfoMsgFile, G_FILE_TEST_EXISTS) ||
-	    ! g_file_get_contents (GdmInfoMsgFile, &InfoMsg, &InfoMsgLength, NULL))
-		return;
-
-	if (InfoMsgLength <= 0) {
-		g_free (InfoMsg);
-		return;
-	}
-
-	gdm_wm_focus_new_windows (TRUE);
-	dialog = gtk_dialog_new_with_buttons (NULL /* Message */,
-					      NULL /* parent */, GTK_DIALOG_MODAL |
-					      GTK_DIALOG_DESTROY_WITH_PARENT,
-					      GTK_STOCK_OK, GTK_RESPONSE_OK,
-					      NULL);
-	label = gtk_label_new (InfoMsg);
-
-	if (GdmInfoMsgFont && strlen(GdmInfoMsgFont) > 0) {
-		PangoFontDescription *GdmInfoMsgFontDesc = pango_font_description_from_string (GdmInfoMsgFont);
-		if (GdmInfoMsgFontDesc) {
-			gtk_widget_modify_font (label, GdmInfoMsgFontDesc);
-			pango_font_description_free (GdmInfoMsgFontDesc);
-		}
-	}
-
-	gtk_container_add (GTK_CONTAINER (GTK_DIALOG (dialog)->vbox), label);
-	gtk_widget_show_all (dialog);
-	gdm_wm_center_window (GTK_WINDOW (dialog));
-
-	gdm_common_setup_cursor (GDK_LEFT_PTR);
-
-	gdm_wm_no_login_focus_push();
-	gtk_dialog_run (GTK_DIALOG (dialog));
-	gtk_widget_destroy (dialog);
-	gdm_wm_no_login_focus_pop();
-
-	g_free (InfoMsg);
-}
-
-void
-gdm_common_message (const gchar *msg)
-{
-	GtkWidget *req = NULL;
-
-	/* we should be now fine for focusing new windows */
-	gdm_wm_focus_new_windows (TRUE);
-
-	req = ve_hig_dialog_new (NULL /* parent */,
-				 GTK_DIALOG_MODAL /* flags */,
-				 GTK_MESSAGE_INFO,
-				 GTK_BUTTONS_OK,
-				 FALSE /* markup */,
-				 msg,
-				 /* avoid warning */ "%s", "");
-
-	gdm_wm_center_window (GTK_WINDOW (req));
-
-	gdm_wm_no_login_focus_push ();
-	gtk_dialog_run (GTK_DIALOG (req));
-	gtk_widget_destroy (req);
-	gdm_wm_no_login_focus_pop ();
-}
-
-gint
-gdm_common_query (const gchar *msg,
-		  gboolean markup,
-		  const char *posbutton,
-		  const char *negbutton,
-		  gboolean has_cancel)
-{
-	int ret;
-	GtkWidget *req;
-	GtkWidget *button;
-
-	/* we should be now fine for focusing new windows */
-	gdm_wm_focus_new_windows (TRUE);
-
-	req = ve_hig_dialog_new (NULL /* parent */,
-				 GTK_DIALOG_MODAL /* flags */,
-				 GTK_MESSAGE_QUESTION,
-				 GTK_BUTTONS_NONE,
-				 markup,
-				 msg,
-				 /* avoid warning */ "%s", "");
-
-	if (negbutton != NULL) {
-		button = gtk_button_new_from_stock (negbutton);
-		gtk_dialog_add_action_widget (GTK_DIALOG (req), button, GTK_RESPONSE_NO);
-		GTK_WIDGET_SET_FLAGS (button, GTK_CAN_DEFAULT);
-		gtk_widget_show (button);
-	}
-
-	if (posbutton != NULL) {
-		button = gtk_button_new_from_stock (posbutton);
-		gtk_dialog_add_action_widget (GTK_DIALOG (req), button, GTK_RESPONSE_YES);
-		GTK_WIDGET_SET_FLAGS (button, GTK_CAN_DEFAULT);
-		gtk_widget_show (button);
-	}
-
-	if (has_cancel == TRUE) {
-		button = gtk_button_new_from_stock (GTK_STOCK_CANCEL);
-		gtk_dialog_add_action_widget (GTK_DIALOG (req), button, GTK_RESPONSE_CANCEL);
-		GTK_WIDGET_SET_FLAGS (button, GTK_CAN_DEFAULT);
-		gtk_widget_show (button);
-	}
-
-	if (posbutton != NULL)
-		gtk_dialog_set_default_response (GTK_DIALOG (req), GTK_RESPONSE_YES);
-	else if (negbutton != NULL)
-		gtk_dialog_set_default_response (GTK_DIALOG (req), GTK_RESPONSE_NO);
-	else if (has_cancel)
-		gtk_dialog_set_default_response (GTK_DIALOG (req), GTK_RESPONSE_CANCEL);
-
-	gdm_wm_center_window (GTK_WINDOW (req));
-
-	gdm_wm_no_login_focus_push ();
-	ret = gtk_dialog_run (GTK_DIALOG (req));
-	gdm_wm_no_login_focus_pop ();
-	gtk_widget_destroy (req);
-
-	return ret;
-}
+#include "gdmcomm.h"
 
 void
 gdm_common_abort (const gchar *format, ...)
@@ -178,7 +47,6 @@ gdm_common_abort (const gchar *format, ...)
     gchar *s;
 
     if (!format) {
-	gdm_kill_thingies ();
 	_exit (DISPLAY_GREETERFAILED);
     }
 
@@ -187,11 +55,10 @@ gdm_common_abort (const gchar *format, ...)
     va_end (args);
     
     syslog (LOG_ERR, "%s", s);
-    closelog();
+    closelog ();
 
     g_free (s);
 
-    gdm_kill_thingies ();
     _exit (DISPLAY_GREETERFAILED);
 }
 
@@ -239,7 +106,9 @@ gdm_common_int_same (VeConfig *config, int cur, const char *key)
 }
 
 void
-gdm_common_login_sound (void)
+gdm_common_login_sound (const gchar *GdmSoundProgram,
+			const gchar *GdmSoundOnLoginReadyFile,
+			gboolean     GdmSoundOnLoginReady)
 {
 	if ( ! GdmSoundOnLoginReady)
 		return;
@@ -361,3 +230,155 @@ gdm_setup_blinking_entry (GtkWidget *entry)
 	entries = g_slist_prepend (entries, eb);
 }
 
+GdkPixbuf *
+gdm_common_get_face (const char *filename,
+		     const char *fallback_filename,
+		     guint       max_width,
+		     guint       max_height)
+{
+	GdkPixbuf *pixbuf    = NULL;
+
+	/* If we don't have a filename then try the fallback */
+	if (! filename) {
+		GtkIconTheme *theme;
+		int           icon_size = 48;
+
+		/* If we don't have a fallback then return NULL */
+		if (! fallback_filename)
+			return NULL;
+
+		/* Try to load an icon from the theme before the fallback */
+		theme = gtk_icon_theme_get_default ();
+		pixbuf = gtk_icon_theme_load_icon (theme, "stock_person", icon_size, 0, NULL);
+		if (! pixbuf)
+			pixbuf = gdk_pixbuf_new_from_file (fallback_filename, NULL);
+	} else {
+		pixbuf = gdk_pixbuf_new_from_file (filename, NULL);
+	}
+
+	if (pixbuf) {
+		guint w, h;
+	
+		w = gdk_pixbuf_get_width (pixbuf);
+		h = gdk_pixbuf_get_height (pixbuf);
+
+		if (w > h && w > max_width) {
+			h = h * ((gfloat) max_width / w);
+			w = max_width;
+		} else if (h > max_height) {
+			w = w * ((gfloat) max_height / h);
+			h = max_height;
+		}
+
+		if (w != gdk_pixbuf_get_width (pixbuf) ||
+		    h != gdk_pixbuf_get_height (pixbuf)) {
+			GdkPixbuf *img;
+
+			img = gdk_pixbuf_scale_simple (pixbuf, w, h, GDK_INTERP_BILINEAR);
+			g_object_unref (pixbuf);
+			pixbuf = img;
+		}
+        }
+
+	return pixbuf;
+}
+
+gchar * 
+gdm_common_get_config_file (void)
+{
+	gchar *result;
+	gchar *config_file;
+
+	/* Get config file */
+	result = gdmcomm_call_gdm ("GET_CONFIG_FILE", NULL /* auth cookie */, "2.8.0.2", 5);
+	if (! result)
+		return NULL;
+
+	if (ve_string_empty (result) ||
+		strncmp (result, "OK ", 3) != 0) {
+		g_free (result);
+		return NULL;
+	}
+
+	/* skip the "OK " */
+	config_file = g_strdup (result + 3);
+
+	g_free (result);
+
+	return config_file;
+}
+
+gboolean
+gdm_common_select_time_format (VeConfig *config)
+{
+	gchar *val;
+
+	g_return_val_if_fail (config != NULL, FALSE);
+
+	val = ve_config_get_string (config, GDM_KEY_USE_24_CLOCK);
+
+	if (val != NULL &&
+	    (val[0] == 'T' ||
+	     val[0] == 't' ||
+	     val[0] == 'Y' ||
+	     val[0] == 'y' ||
+	     atoi (val) != 0)) {
+		g_free (val);
+		return TRUE;
+	} else if (val != NULL &&
+	    (val[0] == 'F' ||
+	     val[0] == 'f' ||
+	     val[0] == 'N' ||
+	     val[0] == 'n')) {
+		g_free (val);
+		return FALSE;
+	} else {
+		/* Value is "auto" (default), thus select according to
+		   "locale" settings. */
+		g_free(val);
+
+		/* Translators: Translate this to '12-hour', or
+		   '24-hour'. Meaning of the translation is the
+		   default time format in your locale. */
+		return strcmp("12-hour", _("24-hour")) != 0;
+		/* Logic is that if translator does not understand the
+		   comment, then 24 hour format is selected. */
+	}
+	/* NOTREACHED */
+	return TRUE;
+}
+
+/* Not to look too shaby on Xinerama setups */
+void
+setup_background_color (gchar *bg_color)
+{
+  GdkColormap *colormap;
+  GdkColor color;
+
+  if (bg_color == NULL ||
+      bg_color[0] == '\0' ||
+      ! gdk_color_parse (bg_color, &color))
+    {
+      gdk_color_parse ("#007777", &color);
+    }
+
+  g_free (bg_color);
+
+  colormap = gdk_drawable_get_colormap
+          (gdk_get_default_root_window ());
+  /* paranoia */
+  if (colormap != NULL)
+    {
+      gboolean success;
+      gdk_error_trap_push ();
+
+      gdk_colormap_alloc_colors (colormap, &color, 1,
+                                 FALSE, TRUE, &success);
+      gdk_window_set_background (gdk_get_default_root_window (), &color);
+      gdk_window_clear (gdk_get_default_root_window ());
+
+      gdk_flush ();
+      gdk_error_trap_pop ();
+    }
+}
+
