@@ -1,4 +1,4 @@
-/* GDM - The Gnome Display Manager
+/* GDM - The GNOME Display Manager
  * Copyright (C) 1999, 2000 Martin K. Petersen <mkp@mkp.net>
  *
  * This file Copyright (c) 2001 George Lebl
@@ -49,6 +49,8 @@ struct _Language {
  * languages, just their names and where they are placed in the menu.
  * The available languages come from the supplied locale.alias */
 static Language languages [] = {
+	/*Note translate the A-M to the A-M you used in the group label */
+	{ N_("A-M|Afrikaans"), "af_ZA", NULL, 0 },
 	/*Note translate the A-M to the A-M you used in the group label */
 	{ N_("A-M|Albanian"), "sq_AL", "Shqip", 0 },
 	/*Note translate the A-M to the A-M you used in the group label */
@@ -58,7 +60,7 @@ static Language languages [] = {
 	/*Note translate the A-M to the A-M you used in the group label */
 	{ N_("A-M|Arabic (Lebanon)"), "ar_LB", NULL, 0 },
 	/*Note translate the A-M to the A-M you used in the group label */
-	{ N_("A-M|Armenian"), "hy_AM", NULL, 0 },
+	{ N_("A-M|Armenian"), "hy_AM", "Հայերեն", 0 },
 	/*Note translate the A-M to the A-M you used in the group label */
 	{ N_("A-M|Azerbaijani"), "az_AZ", "Azərbaycanca", 0 },
 	/*Note translate the A-M to the A-M you used in the group label */
@@ -76,9 +78,13 @@ static Language languages [] = {
 	/*Note translate the A-M to the A-M you used in the group label */
 	{ N_("A-M|Catalan"), "ca_ES", "Català", 0 },
 	/*Note translate the A-M to the A-M you used in the group label */
-	{ N_("A-M|Chinese (simplified)"), "zh_CN", "中文 (简体)", 0 },
+	{ N_("A-M|Chinese (China Mainland)"), "zh_CN", "中文 (中国大陆)", 0 },
 	/*Note translate the A-M to the A-M you used in the group label */
-	{ N_("A-M|Chinese (traditional)"), "zh_TW", "中文 (繁體)", 0 },
+	{ N_("A-M|Chinese (Hong Kong)"), "zh_HK", "中文 (香港)", 0 },
+	/*Note translate the A-M to the A-M you used in the group label */
+	{ N_("A-M|Chinese (Singapore)"), "zh_SG", "中文 (新加坡)", 0 },
+	/*Note translate the A-M to the A-M you used in the group label */
+	{ N_("A-M|Chinese (Taiwan)"), "zh_TW", "中文 (台灣)", 0 },
 	/*Note translate the A-M to the A-M you used in the group label */
 	{ N_("A-M|Croatian"), "hr_HR", "Hrvatski", 0 },
 	/*Note translate the A-M to the A-M you used in the group label */
@@ -88,8 +94,6 @@ static Language languages [] = {
 	/*Note translate the A-M to the A-M you used in the group label */
 	{ N_("A-M|Dutch"), "nl_NL", "Nederlands", 0 },
 	/*Note translate the A-M to the A-M you used in the group label */
-	{ N_("A-M|English"), "en", "English", 0 },
-	/*Note translate the A-M to the A-M you used in the group label */
 	{ N_("A-M|English (USA)"), "en_US", "American English", 0 },
 	/*Note translate the A-M to the A-M you used in the group label */
 	{ N_("A-M|English (Australia)"), "en_AU", "Australian English", 0 },
@@ -100,7 +104,9 @@ static Language languages [] = {
 	/*Note translate the A-M to the A-M you used in the group label */
 	{ N_("A-M|English (Ireland)"), "en_IE", "Irish English", 0 },
 	/*Note translate the A-M to the A-M you used in the group label */
-	{ N_("A-M|English (Denmark)"), "en_IE", "Danish English", 0 },
+	{ N_("A-M|English (Denmark)"), "en_DK", "Danish English", 0 },
+	/*Note translate the A-M to the A-M you used in the group label */
+	{ N_("A-M|English (South Africa)"), "en_ZA", "South African English", 0 },
 	/*Note translate the A-M to the A-M you used in the group label */
 	{ N_("A-M|Estonian"), "et_EE", "Eesti", 0 },
 	/*Note translate the A-M to the A-M you used in the group label */
@@ -146,6 +152,8 @@ static Language languages [] = {
 	/*Note translate the A-M to the A-M you used in the group label */
 	{ N_("A-M|Kannada"), "kn_IN", "﻿ಕನ್ನಡ", 0 },
 	/*Note translate the A-M to the A-M you used in the group label */
+        /*Note translate the A-M to the A-M you used in the group label */
+        { N_("A-M|Kinyarwanda"), "rw_RW", "Kinyarwanda", 0 },
 	{ N_("A-M|Korean"), "ko_KR", "한국어", 0 },
 	/*Note translate the A-M to the A-M you used in the group label */
 	{ N_("A-M|Latvian"), "lv_LV", "Latviešu", 0 },
@@ -162,6 +170,8 @@ static Language languages [] = {
         /*Note translate the A-M to the A-M you used in the group label */
         { N_("A-M|Mongolian"), "mn_MN", "Монгол", 0 },
 	/*Note translate the N-Z to the N-Z you used in the group label */
+	{ N_("N-Z|Northern Sotho"), "nso_ZA", "Sesotho sa Leboa", 0 },
+	/*Note translate the N-Z to the N-Z you used in the group label */
 	{ N_("N-Z|Norwegian (bokmal)"), "no_NO", "Norsk (bokmål)", 0 },
 	/*Note translate the N-Z to the N-Z you used in the group label */
 	{ N_("N-Z|Norwegian (nynorsk)"), "nn_NO", "Norsk (nynorsk)", 0 },
@@ -219,6 +229,8 @@ static Language languages [] = {
 	{ N_("N-Z|Welsh"), "cy_GB", "Cymraeg", 0 },
 	/*Note translate the N-Z to the N-Z you used in the group label */
 	{ N_("N-Z|Yiddish"), "yi", "ייִדיש", 0 },
+	/*Note translate the N-Z to the N-Z you used in the group label */
+	{ N_("N-Z|Zulu"), "zu_ZA", "IsiZulu", 0 },
 	/* This is the POSIX/C locale for english, should really be in Other */
 	{ N_("Other|POSIX/C English"), "C", "POSIX/C English", 0 },
 	{ NULL, NULL }
@@ -350,6 +362,8 @@ gdm_lang_name (const char *language,
 		return g_strdup (language);
 
 	encoding = strchr (language, '.');
+	if (encoding == NULL)
+	  encoding = strchr (language, '@'); /* treat a modifier without a codeset as an encoding */
 	if (encoding != NULL)
 		encoding++;
 
@@ -364,16 +378,8 @@ gdm_lang_name (const char *language,
 
 	if (lang->untranslated != NULL && untranslated) {
 		char *full;
-		if (markup) {
-			full = g_strdup_printf
-				("%s (<span lang=\"%s\">%s</span>)",
-				 name,
-				 lang->code,
-				 lang->untranslated);
-		} else {
-			full = g_strdup_printf ("%s (%s)",
-						name, lang->untranslated);
-		}
+		full = g_strdup_printf ("%s (%s)",
+			name, lang->untranslated);
 		g_free (name);
 		name = full;
 	}
@@ -402,13 +408,7 @@ gdm_lang_untranslated_name (const char *language,
 	if (lang == NULL)
 		return NULL;
 
-	if (markup && lang->untranslated != NULL) {
-		return g_strdup_printf ("<span lang=\"%s\">%s</span>",
-					lang->code,
-					lang->untranslated);
-	} else {
-		return g_strdup (lang->untranslated);
-	}
+	return g_strdup (lang->untranslated);
 }
 
 const char *
@@ -473,6 +473,7 @@ gdm_lang_read_locale_file (const char *locale_file)
 	gboolean clean;
 	char *curlocale;
 	char *getsret;
+	char *p;
 
 	if (locale_file == NULL)
 		return NULL;
@@ -531,8 +532,24 @@ gdm_lang_read_locale_file (const char *locale_file)
 		} else {
 			language = g_new0 (Language, 1);
 			language->found = 1;
-			language->name = g_strdup (name);
-			language->code = g_strdup (lang);
+			/* add a space before an open bracket to match
+			   the style used in the internal list.
+			   e.g. change "English(India)" to "English (India)" */
+			p = strchr (name, '(');
+			if (p != NULL && p > name && *(p-1) != ' ') {
+			  *p = 0;
+			  language->name= g_strconcat(name, " (", p+1, NULL);
+			} else
+			  language->name = g_strdup (name);
+ 			/* only store the "lang_country" part of the locale code, so that we notice
+ 			 * if there is more than one encoding of this language. See bug 132629. */
+			p = strchr (lang, '.');
+ 			if (p == NULL)
+ 			  p = strchr (lang, '@');
+ 			if (p != NULL)
+ 			  language->code = g_strndup (lang, (p - lang));
+ 			else
+ 			  language->code = g_strdup (lang);
 			language->untranslated = NULL;
 			g_hash_table_insert (lang_names,
 					     language->code,
